pub struct CachedRenderPipelineId(/* private fields */);Expand description
Index of a cached render pipeline in a PipelineCache.
Implementations
Sourceimpl CachedRenderPipelineId
impl CachedRenderPipelineId
Sourcepub const INVALID: CachedRenderPipelineId
pub const INVALID: CachedRenderPipelineId
An invalid cached render pipeline index, often used to initialize a variable.
pub fn new(id: usize) -> CachedRenderPipelineId
pub fn id(&self) -> usize